@@ -30,7 +30,7 @@ namespace GLib {
 
 		private Marshaller () {}
 		
-		[DllImport ("libglib-2.0-0.dll", CallingConvention = CallingConvention.Cdecl)]
+		[DllImport (Global.GLibNativeDll, CallingConvention = CallingConvention.Cdecl)]
 		static extern void g_free (IntPtr mem);
 
 		public static void Free (IntPtr ptr)
@@ -47,10 +47,10 @@ namespace GLib {
 				g_free (ptrs [i]);
 		}
 
-		[DllImport ("libglib-2.0-0.dll", CallingConvention = CallingConvention.Cdecl)]
+		[DllImport (Global.GLibNativeDll, CallingConvention = CallingConvention.Cdecl)]
 		static extern IntPtr g_filename_to_utf8 (IntPtr mem, int len, IntPtr read, out IntPtr written, out IntPtr error);
 
-		[DllImport("libglib-2.0-0.dll")]
+		[DllImport (Global.GLibNativeDll)]
 		static extern IntPtr g_filename_to_utf8_utf8 (IntPtr mem, int len, IntPtr read, out IntPtr written, out IntPtr error);
 
 		public static string FilenamePtrToString (IntPtr ptr) 
@@ -124,10 +124,10 @@ namespace GLib {
 			return ret;
 		}
 
-		[DllImport ("libglib-2.0-0.dll", CallingConvention = CallingConvention.Cdecl)]
+		[DllImport (Global.GLibNativeDll, CallingConvention = CallingConvention.Cdecl)]
 		static extern IntPtr g_filename_from_utf8 (IntPtr mem, int len, IntPtr read, out IntPtr written, out IntPtr error);
 
-		[DllImport("libglib-2.0-0.dll")]
+		[DllImport (Global.GLibNativeDll)]
 		static extern IntPtr g_filename_from_utf8_utf8 (IntPtr mem, int len, IntPtr read, out IntPtr written, out IntPtr error);
 
 		public static IntPtr StringToFilenamePtr (string str) 
@@ -170,7 +170,7 @@ namespace GLib {
 				return ret.Replace ("%", "%%");
 		}
 
-		internal static IntPtr StringArrayToStrvPtr (string[] strs)
+		public static IntPtr StringArrayToStrvPtr (string[] strs)
 		{
 			IntPtr[] ptrs = StringArrayToNullTermPointer (strs);
 			IntPtr ret = g_malloc (new UIntPtr ((ulong) (ptrs.Length * IntPtr.Size)));
@@ -178,6 +178,11 @@ namespace GLib {
 			return ret;
 		}
 
+		public static IntPtr StringArrayToNullTermStrvPointer (string[] strs)
+		{
+			return StringArrayToStrvPtr (strs);
+		}
+
 		public static IntPtr[] StringArrayToNullTermPointer (string[] strs)
 		{
 			if (strs == null)
@@ -189,7 +194,7 @@ namespace GLib {
 			return result;
 		}
 
-		[DllImport ("libglib-2.0-0.dll", CallingConvention = CallingConvention.Cdecl)]
+		[DllImport (Global.GLibNativeDll, CallingConvention = CallingConvention.Cdecl)]
 		static extern void g_strfreev (IntPtr mem);
 
 		public static void StrFreeV (IntPtr null_term_array)
@@ -228,22 +233,13 @@ namespace GLib {
 			string[] members = new string[count];
 			for (int i = 0; i < count; ++i) {
 				IntPtr s = Marshal.ReadIntPtr (string_array, i * IntPtr.Size);
-				members[i] = GLib.Marshaller.PtrToStringGFree (s);
+				members[i] = PtrToStringGFree (s);
 			}
-			GLib.Marshaller.Free (string_array);
+			Free (string_array);
 			return members;
 		}
 
-		// Argv marshalling -- unpleasantly complex, but
-		// don't know of a better way to do it.
-		//
-		// Currently, the 64-bit cleanliness is
-		// hypothetical. It's also ugly, but I don't know of a
-		// construct to handle both 32 and 64 bitness
-		// transparently, since we need to alloc buffers of
-		// [native pointer size] * [count] bytes.
-
-		[DllImport ("libglib-2.0-0.dll", CallingConvention = CallingConvention.Cdecl)]
+		[DllImport (Global.GLibNativeDll, CallingConvention = CallingConvention.Cdecl)]
 		static extern IntPtr g_malloc(UIntPtr size);
 
 		public static IntPtr Malloc (ulong size)
@@ -251,115 +247,23 @@ namespace GLib {
 			return g_malloc (new UIntPtr (size));
 		}
 
-		static bool check_sixtyfour () {
-			int szint = Marshal.SizeOf (typeof (int));
-			int szlong = Marshal.SizeOf (typeof (long));
-			int szptr = IntPtr.Size;
+		static System.DateTime local_epoch = new System.DateTime (1970, 1, 1, 0, 0, 0);
+		static int utc_offset = (int) (System.TimeZone.CurrentTimeZone.GetUtcOffset (System.DateTime.Now)).TotalSeconds;
 
-			if (szptr == szint)
-				return false;
-			if (szptr == szlong)
-				return true;
-
-			throw new Exception ("Pointers are neither int- nor long-sized???");
-		}
-
-		static IntPtr make_buf_32 (string[] args) 
-		{
-			int[] ptrs = new int[args.Length];
-
-			for (int i = 0; i < args.Length; i++)
-				ptrs[i] = (int) Marshal.StringToHGlobalAuto (args[i]);
-
-			IntPtr buf = g_malloc (new UIntPtr ((ulong) Marshal.SizeOf(typeof(int)) * 
-					       (ulong) args.Length));
-			Marshal.Copy (ptrs, 0, buf, ptrs.Length);
-			return buf;
-		}
-
-		static IntPtr make_buf_64 (string[] args) 
-		{
-			long[] ptrs = new long[args.Length];
-
-			for (int i = 0; i < args.Length; i++)
-				ptrs[i] = (long) Marshal.StringToHGlobalAuto (args[i]);
-				
-			IntPtr buf = g_malloc (new UIntPtr ((ulong) Marshal.SizeOf(typeof(long)) * 
-					       (ulong) args.Length));
-			Marshal.Copy (ptrs, 0, buf, ptrs.Length);
-			return buf;
-		}
-
-		[Obsolete ("Use GLib.Argv instead to avoid leaks.")]
-		public static IntPtr ArgvToArrayPtr (string[] args)
-		{
-			if (args.Length == 0)
-				return IntPtr.Zero;
-
-			if (check_sixtyfour ())
-				return make_buf_64 (args);
-
-			return make_buf_32 (args);
-		}
-
-		// should we be freeing these pointers? they're marshalled
-		// from our own strings, so I think not ...
-
-		static string[] unmarshal_32 (IntPtr buf, int argc)
-		{
-			int[] ptrs = new int[argc];
-			string[] args = new string[argc];
-
-			Marshal.Copy (buf, ptrs, 0, argc);
-
-			for (int i = 0; i < ptrs.Length; i++)
-				args[i] = Marshal.PtrToStringAuto ((IntPtr) ptrs[i]);
-			
-			return args;
-		}
-
-		static string[] unmarshal_64 (IntPtr buf, int argc)
-		{
-			long[] ptrs = new long[argc];
-			string[] args = new string[argc];
-
-			Marshal.Copy (buf, ptrs, 0, argc);
-
-			for (int i = 0; i < ptrs.Length; i++)
-				args[i] = Marshal.PtrToStringAuto ((IntPtr) ptrs[i]);
-			
-			return args;
-		}		
-
-		[Obsolete ("Use GLib.Argv instead to avoid leaks.")]
-		public static string[] ArrayPtrToArgv (IntPtr array, int argc)
-		{
-			if (argc == 0)
-				return new string[0];
-
-			if (check_sixtyfour ())
-				return unmarshal_64 (array, argc);
-
-			return unmarshal_32 (array, argc);
-		}
-
-		static DateTime local_epoch = new DateTime (1970, 1, 1, 0, 0, 0);
-		static int utc_offset = (int) (TimeZone.CurrentTimeZone.GetUtcOffset (DateTime.Now)).TotalSeconds;
-
-		public static IntPtr DateTimeTotime_t (DateTime time)
+		public static IntPtr DateTimeTotime_t (System.DateTime time)
 		{
 			return new IntPtr (((long)time.Subtract (local_epoch).TotalSeconds) - utc_offset);
 		}
 
-		public static DateTime time_tToDateTime (IntPtr time_t)
+		public static System.DateTime time_tToDateTime (IntPtr time_t)
 		{
 			return local_epoch.AddSeconds (time_t.ToInt64 () + utc_offset);
 		}
 
-		[DllImport ("libglib-2.0-0.dll", CallingConvention = CallingConvention.Cdecl)]
+		[DllImport (Global.GLibNativeDll, CallingConvention = CallingConvention.Cdecl)]
 		static extern IntPtr g_malloc0 (UIntPtr size);
 
-		[DllImport ("libglib-2.0-0.dll", CallingConvention = CallingConvention.Cdecl)]
+		[DllImport (Global.GLibNativeDll, CallingConvention = CallingConvention.Cdecl)]
 		static extern int g_unichar_to_utf8 (uint c, IntPtr buf);
 
 		public static char GUnicharToChar (uint ucs4_char)
@@ -384,7 +288,7 @@ namespace GLib {
 			return PtrToStringGFree (buf);
 		}
 
-		[DllImport ("libglib-2.0-0.dll", CallingConvention = CallingConvention.Cdecl)]
+		[DllImport (Global.GLibNativeDll, CallingConvention = CallingConvention.Cdecl)]
 		static extern IntPtr g_utf16_to_ucs4 (ref ushort c, IntPtr len, IntPtr d1, IntPtr d2, IntPtr d3);
 
 		public static uint CharToGUnichar (char c)
@@ -458,6 +362,39 @@ namespace GLib {
 
 			return result;
 		}
+
+		public static T[] StructArrayFromNullTerminatedIntPtr<T> (IntPtr array)
+		{
+			var res = new List<T> ();
+			IntPtr current = array;
+			T currentStruct = default(T);
+
+			while (current != IntPtr.Zero) {
+				Marshal.PtrToStructure (current, currentStruct);
+				res.Add (currentStruct);
+				current = (IntPtr) ((long)current + Marshal.SizeOf (typeof (T)));
+			}
+
+			return res.ToArray ();
+		}
+
+		public static IntPtr StructArrayToNullTerminatedStructArrayIntPtr<T> (T[] InputArray)
+		{
+			int intPtrSize = Marshal.SizeOf (typeof (IntPtr));
+			IntPtr mem = Marshal.AllocHGlobal ((InputArray.Length + 1) * intPtrSize);
+
+			for (int i = 0; i < InputArray.Length; i++) {
+				IntPtr structPtr = Marshal.AllocHGlobal (Marshal.SizeOf (typeof (T)));
+				Marshal.StructureToPtr (InputArray[i], structPtr, false);
+				// jump to next pointer
+				Marshal.WriteIntPtr (mem, structPtr);
+				mem = (IntPtr) ((long)mem + intPtrSize);
+			}
+			// null terminate
+			Marshal.WriteIntPtr (mem, IntPtr.Zero);
+
+			return mem;
+		}
 	}
 }
 
