@@ -76,10 +76,10 @@ namespace GLib {
 
 		public static bool WarnOnFinalize { get; set; }
 
-		[DllImport ("libgobject-2.0-0.dll", CallingConvention = CallingConvention.Cdecl)]
+		[DllImport (Global.GObjectNativeDll, CallingConvention = CallingConvention.Cdecl)]
 		static extern IntPtr g_object_ref (IntPtr raw);
 
-		[DllImport ("libgobject-2.0-0.dll", CallingConvention = CallingConvention.Cdecl)]
+		[DllImport (Global.GObjectNativeDll, CallingConvention = CallingConvention.Cdecl)]
 		static extern void g_object_unref (IntPtr raw);
 		
 		public static Object TryGetObject (IntPtr o)
@@ -206,7 +206,6 @@ namespace GLib {
 				AddGInterfaces ();
 				gtype.EnsureClass (); //calls class_init
 
-				AddProperties ();
 				ConnectDefaultHandlers ();
 				InvokeTypeInitializers ();
 				AddInterfaceProperties ();
@@ -225,7 +224,7 @@ namespace GLib {
 					if (!iface.IsAssignableFrom (Type.BaseType)) {
 						GInterfaceInfo info = adapter.Info;
 						info.Data = gtype.Val;
-						g_type_add_interface_static (gtype.Val, adapter.GType.Val, ref info);
+						g_type_add_interface_static (gtype.Val, adapter.GInterfaceGType.Val, ref info);
 						adapters.Add (adapter);
 					}
 				}
@@ -242,6 +241,8 @@ namespace GLib {
 				foreach (GInterfaceAdapter adapter in adapters) {
 					InitializeProperties (adapter, gobject_class_handle);
 				}
+
+				AddProperties (gobject_class_handle);
 			}
 
 			private void InitializeProperties (GInterfaceAdapter adapter, IntPtr gobject_class_handle)
@@ -288,12 +289,11 @@ namespace GLib {
 				HandlersOverriden = true;
 			}
 
-			void AddProperties ()
+			void AddProperties (IntPtr gobject_class_handle)
 			{
 				if (is_first_subclass) {
-					IntPtr declaring_class = gtype.GetClassPtr ();
 					ParamSpec pspec = new ParamSpec ("gtk-sharp-managed-instance", "", "", GType.Pointer, ParamFlags.Writable | ParamFlags.ConstructOnly);
-					g_object_class_install_property (declaring_class, idx, pspec.Handle);
+					g_object_class_install_property (gobject_class_handle, idx, pspec.Handle);
 					idx++;
 				}
 
@@ -341,7 +341,7 @@ namespace GLib {
 						PropertyInfo declared_prop = Type.GetProperty (p.Name, BindingFlags.Public | BindingFlags.Instance);
 						if (declared_prop == null)
 							continue;
-						IntPtr param_spec = FindInterfaceProperty (adapter.GType, property_attr.Name);
+						IntPtr param_spec = FindInterfaceProperty (adapter.GInterfaceGType, property_attr.Name);
 
 						Dictionary<IntPtr, PropertyInfo> props;
 						if (!Properties.TryGetValue (Type, out props)) {
@@ -398,7 +398,7 @@ namespace GLib {
 			}
 		}
 
-		[DllImport ("libgobject-2.0-0.dll", CallingConvention = CallingConvention.Cdecl)]
+		[DllImport (Global.GObjectNativeDll, CallingConvention = CallingConvention.Cdecl)]
 		static extern IntPtr g_param_spec_get_name (IntPtr pspec);
 
 		static IntPtr ConstructorCallback (IntPtr gtypeval, uint n_construct_properties, IntPtr construct_properties)
@@ -430,7 +430,7 @@ namespace GLib {
 			return raw;
 		}
 
-		[DllImport ("libgobject-2.0-0.dll", CallingConvention = CallingConvention.Cdecl)]
+		[DllImport (Global.GObjectNativeDll, CallingConvention = CallingConvention.Cdecl)]
 		static extern void g_object_class_override_property (IntPtr klass, uint prop_id, IntPtr name);
 
 		public static void OverrideProperty (IntPtr oclass, uint property_id, string name)
@@ -446,17 +446,17 @@ namespace GLib {
 			idx++;
 		}
 
-		[DllImport ("libgobject-2.0-0.dll", CallingConvention = CallingConvention.Cdecl)]
+		[DllImport (Global.GObjectNativeDll, CallingConvention = CallingConvention.Cdecl)]
 		static extern IntPtr g_object_class_find_property (IntPtr klass, IntPtr name);
 
-		static IntPtr FindClassProperty (GType type, string name)
+		static IntPtr FindClassProperty (GLib.Object o, string name)
 		{
-			IntPtr g_iface = type.GetDefaultInterfacePtr ();
+			IntPtr gobjectclass = Marshal.ReadIntPtr (o.Handle);
 			IntPtr native_name = GLib.Marshaller.StringToPtrGStrdup (name);
-			return g_object_class_find_property (g_iface, native_name);
+			return g_object_class_find_property (gobjectclass, native_name);
 		}
 
-		[DllImport ("libgobject-2.0-0.dll", CallingConvention = CallingConvention.Cdecl)]
+		[DllImport (Global.GObjectNativeDll, CallingConvention = CallingConvention.Cdecl)]
 		static extern IntPtr g_object_interface_find_property (IntPtr klass, IntPtr name);
 
 		static IntPtr FindInterfaceProperty (GType type, string name)
@@ -466,7 +466,7 @@ namespace GLib {
 			return g_object_interface_find_property (g_iface, native_name);
 		}
 
-		[DllImport ("libgobject-2.0-0.dll", CallingConvention = CallingConvention.Cdecl)]
+		[DllImport (Global.GObjectNativeDll, CallingConvention = CallingConvention.Cdecl)]
 		static extern void g_object_class_install_property (IntPtr klass, uint prop_id, IntPtr param_spec);
 
 		static IntPtr RegisterProperty (GType type, string name, string nick, string blurb, uint property_id, GType property_type, bool can_read, bool can_write)
@@ -544,7 +544,7 @@ namespace GLib {
 			}
 		}
 
-		[DllImport ("libgobject-2.0-0.dll", CallingConvention = CallingConvention.Cdecl)]
+		[DllImport (Global.GObjectNativeDll, CallingConvention = CallingConvention.Cdecl)]
 		static extern void g_type_add_interface_static (IntPtr gtype, IntPtr iface_type, ref GInterfaceInfo info);
 
 		protected internal static GType RegisterGType (System.Type t)
@@ -582,7 +582,7 @@ namespace GLib {
 			CreateNativeObject (new string [0], new GLib.Value [0]);
 		}
 
-		[DllImport ("libgobject-2.0-0.dll", CallingConvention = CallingConvention.Cdecl)]
+		[DllImport (Global.GObjectNativeDll, CallingConvention = CallingConvention.Cdecl)]
 		static extern IntPtr g_object_new (IntPtr gtype, IntPtr dummy);
 
 		struct GParameter {
@@ -590,7 +590,7 @@ namespace GLib {
 			public GLib.Value val;
 		}
 
-		[DllImport ("libgobject-2.0-0.dll", CallingConvention = CallingConvention.Cdecl)]
+		[DllImport (Global.GObjectNativeDll, CallingConvention = CallingConvention.Cdecl)]
 		static extern IntPtr g_object_newv (IntPtr gtype, int n_params, GParameter[] parms);
 
 		protected virtual void CreateNativeObject (string[] names, GLib.Value[] vals)
@@ -702,7 +702,7 @@ namespace GLib {
 			}
 		}
 
-		[DllImport ("libgobject-2.0-0.dll", CallingConvention = CallingConvention.Cdecl)]
+		[DllImport (Global.GObjectNativeDll, CallingConvention = CallingConvention.Cdecl)]
 		static extern void g_object_get_property (IntPtr obj, IntPtr name, ref GLib.Value val);
 
 		protected GLib.Value GetProperty (string name)
@@ -714,7 +714,7 @@ namespace GLib {
 			return val;
 		}
 
-		[DllImport ("libgobject-2.0-0.dll", CallingConvention = CallingConvention.Cdecl)]
+		[DllImport (Global.GObjectNativeDll, CallingConvention = CallingConvention.Cdecl)]
 		static extern void g_object_set_property (IntPtr obj, IntPtr name, ref GLib.Value val);
 
 		protected void SetProperty (string name, GLib.Value val)
@@ -724,7 +724,7 @@ namespace GLib {
 			GLib.Marshaller.Free (native_name);
 		}
 
-		[DllImport ("libgobject-2.0-0.dll", CallingConvention = CallingConvention.Cdecl)]
+		[DllImport (Global.GObjectNativeDll, CallingConvention = CallingConvention.Cdecl)]
 		static extern void g_object_notify (IntPtr obj, IntPtr property_name);
 
 		protected void Notify (string property_name)
@@ -785,10 +785,10 @@ namespace GLib {
 			Signal.OverrideDefaultHandler (gtype, name, cb);
 		}
 
-		[DllImport ("libgobject-2.0-0.dll", CallingConvention = CallingConvention.Cdecl)]
+		[DllImport (Global.GObjectNativeDll, CallingConvention = CallingConvention.Cdecl)]
 		protected static extern void g_signal_chain_from_overridden (IntPtr args, ref GLib.Value retval);
 
-		[DllImport ("libgobject-2.0-0.dll", CallingConvention = CallingConvention.Cdecl)]
+		[DllImport (Global.GObjectNativeDll, CallingConvention = CallingConvention.Cdecl)]
 		static extern bool g_type_check_instance_is_a (IntPtr obj, IntPtr gtype);
 
 		internal static bool IsObject (IntPtr obj)
